@@ -1,18 +1,12 @@
 import freeOrionAIInterface as fo
 import math
 import random
+from collections.abc import Iterable, Sequence
 from logging import debug, error, warning
 from operator import itemgetter
 from typing import (
-    Dict,
-    FrozenSet,
-    Iterable,
-    List,
     NamedTuple,
     NewType,
-    Sequence,
-    Set,
-    Tuple,
     Union,
 )
 
@@ -75,7 +69,7 @@ from turn_state.design import get_best_ship_info, get_best_ship_ratings
 from universe.system_network import get_neighbors
 
 
-def get_priority_locations() -> FrozenSet[PlanetId]:
+def get_priority_locations() -> frozenset[PlanetId]:
     priority_facilities = [
         "BLD_SHIPYARD_ENRG_SOLAR",
         "BLD_SHIPYARD_CON_GEOINT",
@@ -118,7 +112,7 @@ def translators_wanted() -> int:
     return int(importance)
 
 
-def _get_capital_info() -> Tuple[PlanetId, "fo.planet", SystemId]:
+def _get_capital_info() -> tuple[PlanetId, "fo.planet", SystemId]:
     capital_id = PlanetUtilsAI.get_capital()
     if capital_id is None or capital_id == INVALID_ID:
         homeworld = None
@@ -161,7 +155,7 @@ def get_building_allocations() -> float:
 
 
 # TODO Move Building names to AIDependencies to avoid typos and for IDE-Support
-def generate_production_orders():  # noqa: max-complexity
+def generate_production_orders():  # noqa: C901
     """Generate production orders."""
     # first check ship designs
     # next check for buildings etc, that could be placed on queue regardless of locally available PP
@@ -203,8 +197,7 @@ def generate_production_orders():  # noqa: max-complexity
             for type_id in possible_building_type_ids:
                 building_type = fo.getBuildingType(type_id)
                 debug(
-                    "    %s cost: %s  time: %s"
-                    % (
+                    "    {} cost: {}  time: {}".format(
                         building_type.name,
                         building_type.productionCost(empire.empireID, homeworld.id),
                         building_type.productionTime(empire.empireID, homeworld.id),
@@ -735,8 +728,7 @@ def generate_production_orders():  # noqa: max-complexity
                     else:
                         # TODO: enable location condition reporting a la mapwnd BuildDesignatorWnd
                         warning(
-                            "Enqueing Conc Camp at %s despite building_type.canBeProduced(empire.empireID, pid) reporting %s"
-                            % (planet, can_build_camp)
+                            f"Enqueing Conc Camp at {planet} despite building_type.canBeProduced(empire.empireID, pid) reporting {can_build_camp}"
                         )
     building_expense += _build_scanning_facility()
 
@@ -1111,9 +1103,9 @@ def generate_production_orders():  # noqa: max-complexity
                 if best_design is None:
                     warning(
                         "problem with mil_build_choices;"
-                        " with selector (%s) chose loc (%s), "
-                        "best_design_id (%s), best_design (None) "
-                        "from mil_build_choices: %s" % (selector, loc, best_design_id, mil_build_choices)
+                        f" with selector ({selector}) chose loc ({loc}), "
+                        f"best_design_id ({best_design_id}), best_design (None) "
+                        f"from mil_build_choices: {mil_build_choices}"
                     )
                     continue
             else:
@@ -1215,7 +1207,7 @@ def generate_production_orders():  # noqa: max-complexity
     print_production_queue(after_turn=True)
 
 
-def _get_queued_buildings(pid: PlanetId) -> List[BuildingName]:
+def _get_queued_buildings(pid: PlanetId) -> list[BuildingName]:
     debug("Buildings already in Production Queue:")
     capital_queued_buildings = _get_queued_buildings_for_planet(pid)
     for bldg in capital_queued_buildings:
@@ -1279,7 +1271,7 @@ def already_has_completed_colony_building(planet_id) -> bool:
     return any(universe.getBuilding(bldg).name.startswith("BLD_COL_") for bldg in planet.buildingIDs)
 
 
-def _build_ship_facilities(building_type: Shipyard, top_pids: Set[PlanetId] = frozenset()) -> None:
+def _build_ship_facilities(building_type: Shipyard, top_pids: set[PlanetId] = frozenset()) -> None:
     # TODO: add total_pp checks below, so don't overload queue
     if not building_type.available():
         return
@@ -1337,7 +1329,7 @@ def _build_ship_facilities(building_type: Shipyard, top_pids: Set[PlanetId] = fr
             already_covered.extend(get_owned_planets_in_system(universe.getPlanet(pid).systemID))
 
 
-def find_automatic_historic_analyzer_candidates() -> List[int]:
+def find_automatic_historic_analyzer_candidates() -> list[int]:
     """
     Find possible locations for the BLD_AUTO_HISTORY_ANALYSER building and return a subset of chosen building locations.
 
@@ -1393,33 +1385,6 @@ def find_automatic_historic_analyzer_candidates() -> List[int]:
     return chosen_locations
 
 
-def get_number_of_queued_outpost_and_colony_ships() -> int:
-    """
-    Get the total number of queued outpost/colony ships/bases.
-    """
-    num_ships = 0
-    considered_ship_roles = (
-        ShipRoleType.CIVILIAN_OUTPOST,
-        ShipRoleType.BASE_OUTPOST,
-        ShipRoleType.BASE_COLONISATION,
-        ShipRoleType.CIVILIAN_COLONISATION,
-    )
-    for element in fo.getEmpire().productionQueue:
-        if element.turnsLeft >= 0 and element.buildType == EmpireProductionTypes.BT_SHIP:
-            if get_aistate().get_ship_role(element.designID) in considered_ship_roles:
-                num_ships += element.blocksize
-    return num_ships
-
-
-def get_number_of_existing_outpost_and_colony_ships() -> int:
-    """
-    Get the total number of existing outpost/colony ships/bases.
-    """
-    num_colony_fleets = len(FleetUtilsAI.get_empire_fleet_ids_by_role(MissionType.COLONISATION))
-    num_outpost_fleets = len(FleetUtilsAI.get_empire_fleet_ids_by_role(MissionType.OUTPOST))
-    return num_outpost_fleets + num_colony_fleets
-
-
 def _location_rating(planet: fo.planet) -> float:
     """Get a rating how good this planet would be for a building"""
     # Simple value so far, should be enhanced, e.g. a scanner should go to the planet with species that
@@ -1533,7 +1498,7 @@ def _build_scanning_facility() -> float:
     return _may_enqueue_for_stability(building_type, turn_cost)
 
 
-def _build_gas_giant_generator() -> float:  # noqa: max-complexity
+def _build_gas_giant_generator() -> float:  # noqa: C901
     """Consider building Gas Giant Generators, return added turn costs."""
     building_type = BuildingType.GAS_GIANT_GEN
     if not building_type.available():
@@ -1636,7 +1601,7 @@ def _build_regional_administration() -> float:
     return _try_enqueue(building_type, get_owned_planets_in_system(best_sys_id))
 
 
-def _rate_system_for_admin(sys_id: SystemId, systems_that_may_profit: List[Tuple[int, SystemId]]) -> float:
+def _rate_system_for_admin(sys_id: SystemId, systems_that_may_profit: list[tuple[int, SystemId]]) -> float:
     opinion = BuildingType.REGIONAL_ADMIN.get_opinions()
     planets = set(get_owned_planets_in_system(sys_id))
     dislikes = planets & opinion.dislikes
@@ -1681,16 +1646,16 @@ def _build_military_command() -> float:
     return 0.0
 
 
-TopPilotSystems = NewType("TopPilotSystems", Dict[SystemId, List[Tuple[PlanetId, float]]])
+TopPilotSystems = NewType("TopPilotSystems", dict[SystemId, list[tuple[PlanetId, float]]])
 
 
 class ShipYardInfo(NamedTuple):
-    queued_shipyard_pids: List[PlanetId]
-    colony_systems: Dict[PlanetId, SystemId]
+    queued_shipyard_pids: list[PlanetId]
+    colony_systems: dict[PlanetId, SystemId]
     top_pilot_systems: TopPilotSystems
 
 
-def _build_basic_shipyards() -> ShipYardInfo:  # noqa: max-complexity
+def _build_basic_shipyards() -> ShipYardInfo:  # noqa: C901
     """
     Consider building basic ship yards and also determine some value needed for other shipyard buildings.
     """
@@ -1753,12 +1718,12 @@ def _build_basic_shipyards() -> ShipYardInfo:  # noqa: max-complexity
     return ShipYardInfo(queued_shipyard_pids, colony_systems, top_pilot_systems)  # TBD return added costs?
 
 
-def _build_energy_shipyards(  # noqa: max-complexity
-    queued_shipyard_pids: List[PlanetId],
-    colony_systems: Dict[PlanetId, SystemId],
+def _build_energy_shipyards(  # noqa: C901
+    queued_shipyard_pids: list[PlanetId],
+    colony_systems: dict[PlanetId, SystemId],
     building_ratio: float,
     building_expense: float,
-) -> Tuple[List[Tuple[float, PlanetId]], List[Tuple[float, PlanetId]], float]:
+) -> tuple[list[tuple[float, PlanetId]], list[tuple[float, PlanetId]], float]:
     """
     Consider building Energy Compressor and Solar Containment Unit.
     Also determines pilot rating for planets in system with red stars and black holes.
@@ -1835,8 +1800,8 @@ def _build_energy_shipyards(  # noqa: max-complexity
     return blackhole_pilots, red_pilots, building_expense
 
 
-def _build_asteroid_processor(  # noqa: max-complexity
-    top_pilot_systems: TopPilotSystems, queued_shipyard_pids: List[PlanetId]
+def _build_asteroid_processor(  # noqa: C901
+    top_pilot_systems: TopPilotSystems, queued_shipyard_pids: list[PlanetId]
 ) -> float:
     """Consider building asteroid processor, return added turn costs."""
     building_type = Shipyard.ASTEROID
@@ -1919,7 +1884,7 @@ def _build_asteroid_processor(  # noqa: max-complexity
     return building_expense
 
 
-def _build_orbital_drydock(top_pilot_systems: TopPilotSystems) -> None:  # noqa: max-complexity
+def _build_orbital_drydock(top_pilot_systems: TopPilotSystems) -> None:  # noqa: C901
     """Consider building orbital drydocks."""
     building_type = Shipyard.ORBITAL_DRYDOCK
     if building_type.available():
