@@ -1,4 +1,5 @@
-from typing import FrozenSet, Iterable, OrderedDict, Tuple
+from collections import OrderedDict
+from collections.abc import Iterable
 
 from common.fo_typing import PlanetId, SpeciesName
 from freeorion_tools.caching import cache_for_current_turn
@@ -7,20 +8,20 @@ _the_planner = None
 
 
 @cache_for_current_turn
-def colonies_targeted() -> FrozenSet[PlanetId]:
+def colonies_targeted() -> frozenset[PlanetId]:
     return _the_planner.colonies_targeted()
 
 
 @cache_for_current_turn
-def outposts_targeted() -> FrozenSet[PlanetId]:
+def outposts_targeted() -> frozenset[PlanetId]:
     return _the_planner.outposts_targeted()
 
 
-def get_colonisable_planet_ids(include_targeted: bool = False) -> OrderedDict[PlanetId, Tuple[float, SpeciesName]]:
+def get_colonisable_planet_ids(include_targeted: bool = False) -> OrderedDict[PlanetId, tuple[float, SpeciesName]]:
     return _the_planner.get_colonisable_planet_ids(include_targeted)
 
 
-def get_colonisable_outpost_ids(include_targeted: bool = False) -> OrderedDict[PlanetId, Tuple[float, SpeciesName]]:
+def get_colonisable_outpost_ids(include_targeted: bool = False) -> OrderedDict[PlanetId, tuple[float, SpeciesName]]:
     return _the_planner.get_colonisable_outpost_ids(include_targeted)
 
 
