@@ -10,11 +10,11 @@ handlers = {
 
 def _register(function_name, handler, is_post_handler):
     handlers.setdefault(function_name, [[], []])[is_post_handler].append(handler)
-    print('Register "%s" %s "%s" execution' % (
-        handler.__name__,
-        'after' if is_post_handler else 'before',
-        function_name
-    ))
+    print(
+        'Register "{}" {} "{}" execution'.format(
+            handler.__name__, "after" if is_post_handler else "before", function_name
+        )
+    )
 
 
 def register_pre_handler(function_name, handler):
@@ -42,4 +42,5 @@ def listener(funct):
         res = funct(*args)
         [x(res, *args, **kwargs) for x in post]
         return res
+
     return wrapper
