@@ -1,10 +1,9 @@
+import freeorion as fo
 import sys
 from collections import defaultdict
 from math import acos, ceil, cos, floor, pi, sin, sqrt
 from random import gauss, randint, random, uniform
 
-import freeorion as fo
-
 import universe_tables
 import util
 
@@ -20,7 +19,7 @@ class AdjacencyGrid:
         self.cell_size = min(max(universe_width / 50, self.min_dist), self.max_dist / sqrt(2))
         self.width = int(universe_width / self.cell_size) + 1
         self.grid = defaultdict(set)
-        print("Adjacency Grid: width {}, cell size {}".format(self.width, self.cell_size))
+        print(f"Adjacency Grid: width {self.width}, cell size {self.cell_size}")
 
     def cell(self, pos):
         """Returns cell index."""
@@ -41,8 +40,7 @@ class AdjacencyGrid:
         upper_left_y = max(0, cell_y - radius)
         lower_right_x = min(self.width - 1, cell_x + radius)
         lower_right_y = min(self.width - 1, cell_y + radius)
-        return [(x, y) for x in range(upper_left_x, lower_right_x + 1)
-                for y in range(upper_left_y, lower_right_y + 1)]
+        return [(x, y) for x in range(upper_left_x, lower_right_x + 1) for y in range(upper_left_y, lower_right_y + 1)]
 
     def _generate_rings_around_point(self, pos, max_radius=None):
         """Yields successive rings of indices containing cell."""
@@ -66,12 +64,13 @@ class AdjacencyGrid:
             if i <= i_radius_close_enough:
                 _neighbors += [pos for cell in ring for pos in self.grid[cell]]
             else:
-                _neighbors += [pos for cell in ring for pos in self.grid[cell] if
-                               util.distance(pos, p) <= self.max_dist]
+                _neighbors += [
+                    pos for cell in ring for pos in self.grid[cell] if util.distance(pos, p) <= self.max_dist
+                ]
         return _neighbors
 
     def nearest_neighbor(self, p):
-        """ Return nearest neighbor at any distance."""
+        """Return nearest neighbor at any distance."""
         for ring in self._generate_rings_around_point(p):
             candidates = [pos for cell in ring for pos in self.grid[cell]]
             if candidates:
@@ -84,9 +83,11 @@ class AdjacencyGrid:
         Checks if the specified position is too close to the positions stored in the grid
         """
         pos_cell = self.cell(pos)
-        return any(util.distance(p2, pos) < self.min_dist
-                   for p2_cell in self._square_indices_containing_cell(pos_cell, 1)
-                   for p2 in self.grid[p2_cell])
+        return any(
+            util.distance(p2, pos) < self.min_dist
+            for p2_cell in self._square_indices_containing_cell(pos_cell, 1)
+            for p2 in self.grid[p2_cell]
+        )
 
 
 class DSet:
@@ -98,6 +99,7 @@ class DSet:
 
     A private child class of DisjointSets to store the parent and rank of a disjoint set object
     """
+
     def __init__(self, pos):
         self.pos = pos
 
@@ -132,6 +134,7 @@ class DisjointSets:
 
     See https://en.wikipedia.org/wiki/Disjoint-set_data_structure
     """
+
     def __init__(self):
         self.dsets = {}
 
@@ -141,7 +144,7 @@ class DisjointSets:
             self.dsets[pos] = DSet(pos)
 
     def link(self, p1, p2):
-        """ Creates a link between the sets containing p1 and p2"""
+        """Creates a link between the sets containing p1 and p2"""
         root1 = self.root(p1)
         if p1 == p2:
             # print " self link"
@@ -181,6 +184,7 @@ class DisjointSets:
         Check if pos is the root of a cluster otherwise shorten
         the tree while tranversing it and return the root
         """
+
         # traverse tree and fetch parents for compression
         def parents(p1, children):
             # print "pp p1 ", p1.pos, " children a ", children
@@ -202,7 +206,7 @@ class DisjointSets:
         return [root.pos]
 
     def complete_sets(self):
-        """ returns a list of list of all sets O(n)."""
+        """returns a list of list of all sets O(n)."""
         ret = defaultdict(list)
         for pos in self.dsets.keys():
             ret[self.root(pos)].append(pos)
@@ -217,6 +221,7 @@ class Clusterer:
     Adds all of the seperations less than MAX_STARLANE_LENGTH
     Then returns the clusters of stars when requested
     """
+
     def __init__(self, positions, adjacency_grid):
         self.adjacency_grid = adjacency_grid
         self.dsets = DisjointSets()
@@ -291,8 +296,10 @@ def stitching_positions(p1, p2):
     Returns a list of positions between p1 and p2 between MIN_SYSTEM_SEPARATION and MAX_STARLANE_LENGTH apart
     """
     if 2 * universe_tables.MIN_SYSTEM_SEPARATION >= universe_tables.MAX_STARLANE_LENGTH:
-        util.report_error("MAX_STARLANE_LENGTH must be twice MIN_SYSTEM_SEPARATION to "
-                          "allow extra positions to be added to enforce MAX_STARLANE_LENGTH")
+        util.report_error(
+            "MAX_STARLANE_LENGTH must be twice MIN_SYSTEM_SEPARATION to "
+            "allow extra positions to be added to enforce MAX_STARLANE_LENGTH"
+        )
         return []
 
     max_dist = universe_tables.MAX_STARLANE_LENGTH
@@ -303,13 +310,15 @@ def stitching_positions(p1, p2):
 
     # Pick a random point in an 2:1 ratio ellipse and then rotate and slide it in between p1 and p2
     p1_p2_theta = acos((p2[0] - p1[0]) / p1_p2_dist)
-    p1_p2_scale = (p1_p2_dist - 2*min_dist) / 2
+    p1_p2_scale = (p1_p2_dist - 2 * min_dist) / 2
     p1_p2_translation = ((p1[0] + p2[0]) / 2, (p1[1] + p2[1]) / 2)
 
     radius_0space = uniform(0.0, 1.0)
     angle_0space = uniform(0.0, 2.0 * pi)
-    rotated_point = (radius_0space * p1_p2_scale * cos(angle_0space + p1_p2_theta),
-                     radius_0space * p1_p2_scale * sin(angle_0space + p1_p2_theta))
+    rotated_point = (
+        radius_0space * p1_p2_scale * cos(angle_0space + p1_p2_theta),
+        radius_0space * p1_p2_scale * sin(angle_0space + p1_p2_theta),
+    )
 
     p3 = (rotated_point[0] + p1_p2_translation[0], rotated_point[1] + p1_p2_translation[1])
 
@@ -339,28 +348,32 @@ def enforce_max_distance(positions, adjacency_grid):
     if len(clusterer) == 1:
         print("All systems positioned in a single connected cluster")
     else:
-        print("{} clusters separated by more than the MAX_STARLANE_LENGTH."
-              "  Starting to fill gaps.".format(len(clusterer)))
+        print(f"{len(clusterer)} clusters separated by more than the MAX_STARLANE_LENGTH." "  Starting to fill gaps.")
 
     while len(clusterer) > 1:
         smallest_cluster = clusterer.smallest_isolated_cluster()
-        print("Searching for nearest neighbor position to a cluster "
-              "with {} positions.".format(len(smallest_cluster)))
+        print("Searching for nearest neighbor position to a cluster " f"with {len(smallest_cluster)} positions.")
         for pos in smallest_cluster:
             adjacency_grid.remove_pos(pos)
         # Find nearest neighbour
-        (_, p1, p2) = min([(util.distance(pos, nn), pos, nn)
-                           for pos in smallest_cluster
-                           for nn in [adjacency_grid.nearest_neighbor(pos)] if nn])
+        (_, p1, p2) = min(
+            [
+                (util.distance(pos, nn), pos, nn)
+                for pos in smallest_cluster
+                for nn in [adjacency_grid.nearest_neighbor(pos)]
+                if nn
+            ]
+        )
 
         for pos in smallest_cluster:
             adjacency_grid.insert_pos(pos)
         # Add extra positions
         extra_positions = stitching_positions(p1, p2)
         for i_extra, p3 in enumerate(extra_positions):
-            print("Adding {} of {} extra positions at {} to enforce "
-                  "max spacing between {} and {}.".format(
-                      i_extra + 1, len(extra_positions), p3, p1, p2))
+            print(
+                f"Adding {i_extra + 1} of {len(extra_positions)} extra positions at {p3} to enforce "
+                f"max spacing between {p1} and {p2}."
+            )
             adjacency_grid.insert_pos(p3)
             positions.append(p3)
         clusterer.stitch_clusters(p1, p2, extra_positions)
@@ -368,8 +381,7 @@ def enforce_max_distance(positions, adjacency_grid):
         if len(clusterer) == 1:
             print("All systems now positioned in a single connected cluster")
         else:
-            print("{} clusters separated by more the MAX_STARLANE_LENGTH.  "
-                  "Continuing to fill gaps.".format(len(clusterer)))
+            print(f"{len(clusterer)} clusters separated by more the MAX_STARLANE_LENGTH.  " "Continuing to fill gaps.")
 
 
 def calc_universe_width(shape, size):
@@ -427,9 +439,10 @@ def spiral_galaxy_calc_positions(positions, adjacency_grid, arms, size, width):
             break
 
         if not attempts:
-            print("Spiral galaxy shape: giving up on placing star {}, can't "
-                  "find position sufficiently far from other systems."
-                  .format(i))
+            print(
+                f"Spiral galaxy shape: giving up on placing star {i}, can't "
+                "find position sufficiently far from other systems."
+            )
 
 
 def elliptical_galaxy_calc_positions(positions, adjacency_grid, size, width):
@@ -480,9 +493,10 @@ def elliptical_galaxy_calc_positions(positions, adjacency_grid, size, width):
             break
 
         if not attempts:
-            print("Elliptical galaxy shape: giving up on placing star {}, "
-                  "can't find position sufficiently far from other systems"
-                  .format(i))
+            print(
+                f"Elliptical galaxy shape: giving up on placing star {i}, "
+                "can't find position sufficiently far from other systems"
+            )
 
 
 def disc_galaxy_calc_positions(positions, adjacency_grid, size, width):
@@ -515,17 +529,17 @@ def disc_galaxy_calc_positions(positions, adjacency_grid, size, width):
             break
 
         if not attempts:
-            print("Disc galaxy shape: giving up on placing star {}, can't find"
-                  " position sufficiently far from other systems".format(i))
+            print(
+                f"Disc galaxy shape: giving up on placing star {i}, can't find"
+                " position sufficiently far from other systems"
+            )
 
 
-def cluster_galaxy_calc_positions(positions, adjacency_grid, size, width):
+def cluster_galaxy_calc_positions(  # noqa: C901
+    positions: list[tuple[int, int]], adjacency_grid: AdjacencyGrid, size: int, width: float
+):
     """
-    Calculate positions for the cluster galaxy shape.
-    :type positions: list
-    :type adjacency_grid: AdjacencyGrid
-    :type size: int
-    :type width: float
+    Calculate positions for the cluster galaxy shape and add them to positions.
     """
     if size < 1:
         print("Cluster galaxy requested for less than 1 star", file=sys.stderr)
@@ -555,8 +569,10 @@ def cluster_galaxy_calc_positions(positions, adjacency_grid, size, width):
             x = ((random() * 2.0 - 1.0) / (clusters + 1.0)) * clusters
             y = ((random() * 2.0 - 1.0) / (clusters + 1.0)) * clusters
             # ensure all clusters have a min separation to each other (search isn't optimized, not worth the effort)
-            if all(((cp[0][0] - x) * (cp[0][0] - x) + (cp[0][1] - y) * (cp[0][1] - y)) > (2.0 / clusters)
-                   for cp in clusters_position):
+            if all(
+                ((cp[0][0] - x) * (cp[0][0] - x) + (cp[0][1] - y) * (cp[0][1] - y)) > (2.0 / clusters)
+                for cp in clusters_position
+            ):
                 break
             attempts -= 1
         rotation = uniform(0.0, pi)
@@ -601,9 +617,10 @@ def cluster_galaxy_calc_positions(positions, adjacency_grid, size, width):
             break
 
         if not attempts:
-            print("Cluster galaxy shape: giving up on placing star {}, can't "
-                  "find position sufficiently far from other systems"
-                  .format(i))
+            print(
+                f"Cluster galaxy shape: giving up on placing star {i}, can't "
+                "find position sufficiently far from other systems"
+            )
 
 
 def ring_galaxy_calc_positions(positions, adjacency_grid, size, width):
@@ -638,9 +655,10 @@ def ring_galaxy_calc_positions(positions, adjacency_grid, size, width):
             break
 
         if not attempts:
-            print("Ring galaxy shape: giving up on placing star {}, can't"
-                  " find position sufficiently far from other systems"
-                  .format(i))
+            print(
+                f"Ring galaxy shape: giving up on placing star {i}, can't"
+                " find position sufficiently far from other systems"
+            )
 
 
 def box_galaxy_calc_positions(positions, adjacency_grid, size, width):
@@ -671,8 +689,10 @@ def box_galaxy_calc_positions(positions, adjacency_grid, size, width):
             break
 
         if not attempts:
-            print("Box galaxy shape: giving up on placing star {}, can't find"
-                  " position sufficiently far from other systems".format(i))
+            print(
+                f"Box galaxy shape: giving up on placing star {i}, can't find"
+                " position sufficiently far from other systems"
+            )
 
 
 def irregular_galaxy_calc_positions(positions, adjacency_grid, size, width):
@@ -680,7 +700,7 @@ def irregular_galaxy_calc_positions(positions, adjacency_grid, size, width):
     Calculate positions for the irregular galaxy shape.
     """
     max_delta = max(min(float(universe_tables.MAX_STARLANE_LENGTH), width / 10.0), adjacency_grid.min_dist * 2.0)
-    print("Irregular galaxy shape: max delta distance = {}".format(max_delta))
+    print(f"Irregular galaxy shape: max delta distance = {max_delta}")
     origin_x, origin_y = width / 2.0, width / 2.0
     prev_x, prev_y = origin_x, origin_y
     reset_to_origin = 0
@@ -703,7 +723,7 @@ def irregular_galaxy_calc_positions(positions, adjacency_grid, size, width):
             adjacency_grid.insert_pos(pos)
             positions.append(pos)
         prev_x, prev_y = x, y
-    print("Reset to origin {} times".format(reset_to_origin))
+    print(f"Reset to origin {reset_to_origin} times")
 
 
 def recalc_universe_width(positions):
@@ -721,14 +741,10 @@ def recalc_universe_width(positions):
     min_y = min(positions, key=lambda p: p[1])[1]
     max_x = max(positions, key=lambda p: p[0])[0]
     max_y = max(positions, key=lambda p: p[1])[1]
-    print("...the leftmost system position is at x coordinate {}"
-          .format(min_x))
-    print("...the uppermost system position is at y coordinate {}"
-          .format(min_y))
-    print("...the rightmost system position is at x coordinate {}"
-          .format(max_x))
-    print("...the lowermost system position is at y coordinate {}"
-          .format(max_y))
+    print(f"...the leftmost system position is at x coordinate {min_x}")
+    print(f"...the uppermost system position is at y coordinate {min_y}")
+    print(f"...the rightmost system position is at x coordinate {max_x}")
+    print(f"...the lowermost system position is at y coordinate {max_y}")
 
     # calculate the actual universe width by determining the width and height of an rectangle that encompasses all
     # positions, and take the greater of the two as the new actual width for the universe
@@ -736,23 +752,19 @@ def recalc_universe_width(positions):
     width = max_x - min_x
     height = max_y - min_y
     actual_width = max(width, height) + 20.0
-    print("...recalculated universe width: {}".format(actual_width))
+    print(f"...recalculated universe width: {actual_width}")
 
     # shift all positions so the entire map is centered in a quadratic box of the width we just calculated
     # this box defines the extends of our universe
     delta_x = ((actual_width - width) / 2) - min_x
     delta_y = ((actual_width - height) / 2) - min_y
-    print("...shifting all system positions by {}/{}".format(delta_x, delta_y))
+    print(f"...shifting all system positions by {delta_x}/{delta_y}")
     new_positions = [(p[0] + delta_x, p[1] + delta_y) for p in positions]
 
-    print("...the leftmost system position is now at x coordinate {}"
-          .format(min(new_positions, key=lambda p: p[0])[0]))
-    print("...the uppermost system position is now at y coordinate {}"
-          .format(min(new_positions, key=lambda p: p[1])[1]))
-    print("...the rightmost system position is now at x coordinate {}"
-          .format(max(new_positions, key=lambda p: p[0])[0]))
-    print("...the lowermost system position is now at y coordinate {}"
-          .format(max(new_positions, key=lambda p: p[1])[1]))
+    print(f"...the leftmost system position is now at x coordinate {min(new_positions, key=lambda p: p[0])[0]}")
+    print(f"...the uppermost system position is now at y coordinate {min(new_positions, key=lambda p: p[1])[1]}")
+    print(f"...the rightmost system position is now at x coordinate {max(new_positions, key=lambda p: p[0])[0]}")
+    print(f"...the lowermost system position is now at y coordinate {max(new_positions, key=lambda p: p[1])[1]}")
 
     return actual_width, new_positions
 
@@ -766,13 +778,13 @@ def calc_star_system_positions(gsd):
 
     # calculate typical width for universe based on number of systems
     width = calc_universe_width(gsd.shape, gsd.size)
-    print("Set universe width to {}".format(width))
+    print(f"Set universe width to {width}")
     fo.set_universe_width(width)
 
     positions = []
     adjacency_grid = AdjacencyGrid(width)
 
-    print("Creating {} galaxy shape".format(gsd.shape))
+    print(f"Creating {gsd.shape} galaxy shape")
     if gsd.shape == fo.galaxyShape.spiral2:
         spiral_galaxy_calc_positions(positions, adjacency_grid, 2, gsd.size, width)
     elif gsd.shape == fo.galaxyShape.spiral3:
@@ -800,7 +812,7 @@ def calc_star_system_positions(gsd):
     # to avoid having too much "extra space" around the system positions of our galaxy map, recalculate the universe
     # width and shift all positions accordingly
     width, positions = recalc_universe_width(positions)
-    print("Set universe width to {}".format(width))
+    print(f"Set universe width to {width}")
     fo.set_universe_width(width)
 
     return positions
