@@ -1,9 +1,7 @@
+import freeorion as fo
 import random
 from itertools import cycle
 
-import freeorion as fo
-
-
 # tuples of consonants and vowels for random name generation
 consonants = ("b", "c", "d", "f", "g", "h", "j", "k", "l", "m", "n", "p", "q", "r", "s", "t", "v", "w", "x", "y", "z")
 vowels = ("a", "e", "i", "o", "u")
@@ -19,11 +17,11 @@ def random_name(size):
     It rotates between consonants and vowels.
     Rotation is global first letter depends on prev calls.
     """
-    return ''.join(next(_random_letter_generator) for _ in range(size)).capitalize()
+    return "".join(next(_random_letter_generator) for _ in range(size)).capitalize()
 
 
 def get_name_list(name_list):
     """
     Retrieves a list of names from the string tables.
     """
-    return fo.user_string(name_list).splitlines()
+    return fo.userString(name_list).splitlines()
