@@ -1,5 +1,15 @@
-from common.base_prod import TECH_COST_MULTIPLIER
-from common.priorities import TARGET_POPULATION_AFTER_SCALING_PRIORITY
+from focs._effects import (
+    EffectsGroup,
+    HasSpecies,
+    OwnedBy,
+    SetTargetPopulation,
+    Source,
+    Target,
+    Value,
+)
+from focs._tech import *
+from macros.base_prod import TECH_COST_MULTIPLIER
+from macros.priorities import TARGET_POPULATION_AFTER_SCALING_PRIORITY
 
 Tech(
     name="GRO_SUBTER_HAB",
