@@ -1,4 +1,11 @@
-from common.base_prod import TECH_COST_MULTIPLIER
+from focs._effects import (
+    EmpireHasAdoptedPolicy,
+    IsSource,
+    Source,
+    StatisticIf,
+)
+from focs._tech import *
+from macros.base_prod import TECH_COST_MULTIPLIER
 
 Tech(
     name="PRO_SOL_ORB_GEN",
@@ -10,7 +17,7 @@ Tech(
     * (
         1
         - 0.25
-        * StatisticIf(float, condition=Source & EmpireHasAdoptedPolicy(empire=Source.Owner, name="PLC_INDUSTRIALISM"))
+        * StatisticIf(float, condition=IsSource & EmpireHasAdoptedPolicy(empire=Source.Owner, name="PLC_INDUSTRIALISM"))
     ),
     researchturns=8,
     tags=["PEDIA_PRODUCTION_CATEGORY"],
