@@ -1,3 +1,4 @@
+from focs._tech import *
 from techs.ship_weapons.ship_weapons import WEAPON_BASE_EFFECTS
 
 Tech(
@@ -13,6 +14,10 @@ Tech(
         Item(type=UnlockShipPart, name="GT_TROOP_POD"),
         Item(type=UnlockShipPart, name="SR_WEAPON_0_1"),
     ],
-    effectsgroups=[*WEAPON_BASE_EFFECTS("SR_WEAPON_0_1"), *WEAPON_BASE_EFFECTS("SR_WEAPON_1_1")],
+    effectsgroups=[
+        # TODO move at least the flak effect to the part definition
+        *WEAPON_BASE_EFFECTS("SR_WEAPON_0_1"),
+        *WEAPON_BASE_EFFECTS("SR_WEAPON_1_1"),
+    ],
     graphic="icons/tech/planetary_colonialism.png",
 )
