@@ -1,4 +1,17 @@
-from common.base_prod import TECH_COST_MULTIPLIER
+from focs._effects import (
+    EffectsGroup,
+    IsSource,
+    NamedReal,
+    OwnedBy,
+    OwnerHasTech,
+    Planet,
+    SetDetection,
+    SetEmpireMeter,
+    Source,
+    Value,
+)
+from focs._tech import *
+from macros.base_prod import TECH_COST_MULTIPLIER
 
 Tech(
     name="SPY_DETECT_2",
@@ -19,7 +32,7 @@ Tech(
             effects=SetDetection(value=Value + NamedReal(name="SPY_DETECT_2_RANGE", value=75.0)),
         ),
         EffectsGroup(
-            scope=Source,
+            scope=IsSource,
             activation=~OwnerHasTech(name="SPY_DETECT_3")
             & ~OwnerHasTech(name="SPY_DETECT_4")
             & ~OwnerHasTech(name="SPY_DETECT_5"),
