@@ -1,4 +1,6 @@
-from common.base_prod import TECH_COST_MULTIPLIER
+from focs._effects import AddSpecial, EffectsGroup, HasTag, IsSource, OwnedBy, OwnerHasTech, Planet, Source, StatisticIf
+from focs._tech import *
+from macros.base_prod import TECH_COST_MULTIPLIER
 
 Tech(
     name="SPY_STEALTH_1",
@@ -8,7 +10,7 @@ Tech(
     researchcost=(
         160
         * TECH_COST_MULTIPLIER
-        / (1 + StatisticIf(float, condition=Source & OwnerHasTech(name="SPY_STEALTH_PART_1")))
+        / (1 + StatisticIf(float, condition=IsSource & OwnerHasTech(name="SPY_STEALTH_PART_1")))
         / (1 + StatisticIf(float, condition=OwnedBy(empire=Source.Owner) & HasTag(name="SNEAKY")))
     ),
     researchturns=5,
