@@ -1,4 +1,17 @@
-from common.base_prod import TECH_COST_MULTIPLIER
+from focs._effects import (
+    AddSpecial,
+    EffectsGroup,
+    HasTag,
+    IsSource,
+    OwnedBy,
+    OwnerHasTech,
+    Planet,
+    RemoveSpecial,
+    Source,
+    StatisticIf,
+)
+from focs._tech import *
+from macros.base_prod import TECH_COST_MULTIPLIER
 
 Tech(
     name="SPY_STEALTH_3",
@@ -8,7 +21,7 @@ Tech(
     researchcost=(
         700
         * TECH_COST_MULTIPLIER
-        / (1 + StatisticIf(float, condition=Source & OwnerHasTech(name="SPY_STEALTH_PART_3")))
+        / (1 + StatisticIf(float, condition=IsSource & OwnerHasTech(name="SPY_STEALTH_PART_3")))
         / (1 + StatisticIf(float, condition=OwnedBy(empire=Source.Owner) & HasTag(name="SNEAKY")))
     ),
     researchturns=7,
